package com.inspur.service;

import java.util.List;

import com.inspur.domain.ElevatorWorkNode;

/**
 * 工单节点信息Service接口
 * 
 * @author inspur
 * @date 2024-09-18
 */
public interface IElevatorWorkNodeService 
{
    /**
     * 查询工单节点信息
     * 
     * @param id 工单节点信息主键
     * @return 工单节点信息
     */
    public ElevatorWorkNode selectElevatorWorkNodeById(Long id);

    /**
     * 查询工单节点信息列表
     * 
     * @param elevatorWorkNode 工单节点信息
     * @return 工单节点信息集合
     */
    public List<ElevatorWorkNode> selectElevatorWorkNodeList(ElevatorWorkNode elevatorWorkNode);

    /**
     * 新增工单节点信息
     * 
     * @param elevatorWorkNode 工单节点信息
     * @return 结果
     */
    public int insertElevatorWorkNode(ElevatorWorkNode elevatorWorkNode);

    /**
     * 修改工单节点信息
     * 
     * @param elevatorWorkNode 工单节点信息
     * @return 结果
     */
    public int updateElevatorWorkNode(ElevatorWorkNode elevatorWorkNode);

    /**
     * 批量删除工单节点信息
     * 
     * @param ids 需要删除的工单节点信息主键集合
     * @return 结果
     */
    public int deleteElevatorWorkNodeByIds(Long[] ids);

    /**
     * 删除工单节点信息信息
     * 
     * @param id 工单节点信息主键
     * @return 结果
     */
    public int deleteElevatorWorkNodeById(Long id);
}
